==> dokuwiki_0.0.20131208.orig.tar.gz: dokuwiki-2013-12-08/lib/plugins/acl/lang/zh/lang.php <==
<?php

/**
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 * 
 * @author ZDYX <zhangduyixiong@gmail.com>
 * @author http://www.chinese-tools.com/tools/converter-tradsimp.html
 * @author George Sheraton guxd@163.com
 * @author Simon zhan <simonzhan@21cn.com>
 * @author mr.jinyi@gmail.com
 * @author ben <ben@livetom.com>
 * @author lainme <lainme993@gmail.com>
 * @author caii <zhoucaiqi@gmail.com>
 * @author Hiphen Lee <jacob.b.leung@gmail.com>
 * @author caii, patent agent in China <zhoucaiqi@gmail.com>
 * @author lainme993@gmail.com
 * @author Shuo-Ting Jian <shoting@gmail.com>
 */
$lang['admin_acl']             = '访问控制列表（ACL）管理器';
$lang['acl_group']             = '组';
$lang['acl_user']              = '用户';
$lang['acl_perms']             = '许可给';
$lang['page']                  = '页面';
$lang['namespace']             = '命名空间';
$lang['btn_select']            = '選擇';
$lang['p_user_id']             = '用户 <b class="acluser">%s</b> 当前在页面 <b class="aclpage">%s</b> 拥有以下权限：<i>%s</i>。';
$lang['p_user_ns']             = '用户 <b class="acluser">%s</b> 当前在命名空间 <b class="aclns">%s</b> 拥有以下权限：<i>%s</i>。';
$lang['p_group_id']            = '<b class="aclgroup">%s</b> 组成员当前在页面 <b class="aclpage">%s</b> 拥有以下权限：<i>%s</i>。';
$lang['p_group_ns']            = '<b class="aclgroup">%s</b> 组成员当前在命名空间 <b class="aclns">%s</b> 拥有以下权限：<i>%s</i>。';
$lang['p_choose_id']           = '请在上表中<b>输入用户名或组名称</b>，来查看或编辑页面 <b class="aclpage">%s</b> 的权限设置。';
$lang['p_choose_ns']           = '请在上表中<b>输入用户名或组名称</b>，来查看或编辑命名空间 <b class="aclns">%s</b> 的权限设置。';
$lang['p_inherited']           = '请注意：这些权限并没有明确设定，而是从其他组或更高级的名称空间继承而来。';
$lang['p_isadmin']             = '请注意：选定的组或用户拥有完全权限，因为它被设定为超级用户。';
$lang['p_include']             = '高权限包含低权限。创建、上传和删除权限只能应用于名称空间，而不是单个页面。';
$lang['current']               = '当前 ACL 规则';
$lang['where']                 = '页面/命名空间';
$lang['who']                   = '用户/组';
$lang['perm']                  = '权限';
$lang['acl_perm0']             = '无';
$lang['acl_perm1']             = '读取';
$lang['acl_perm2']             = '编辑';
$lang['acl_perm4']             = '创建';
$lang['acl_perm8']             = '上传';
$lang['acl_perm16']            = '删除';
$lang['acl_new']               = '添加新条目';
$lang['acl_mod']               = '编辑条目';

==> dokuwiki_0.0.20220731.a.orig.tar.gz: dokuwiki-2022-07-31a/lib/plugins/acl/lang/zh/lang.php <==
<?php

/**
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 *
 * @author ZDYX <zhangduyixiong@gmail.com>
 * @author http://www.chinese-tools.com/tools/converter-tradsimp.html
 * @author Simon zhan <simonzhan@21cn.com>
 * @author ben <ben@livetom.com>
 * @author lainme <lainme993@gmail.com>
 * @author caii <zhoucaiqi@gmail.com>
 * @author Hiphen Lee <jacob.b.leung@gmail.com>
 * @author Shuo-Ting Jian <shoting@gmail.com>
 */
$lang['admin_acl']             = '访问控制列表（ACL）管理器';
$lang['acl_group']             = '组:';
$lang['acl_user']              = '用户:';
$lang['acl_perms']             = '许可给';
$lang['page']                  = '页面';
$lang['namespace']             = '命名空间';
$lang['btn_select']            = '选择';
$lang['p_user_id']             = '用户 <b class="acluser">%s</b> 当前在页面 <b class="aclpage">%s</b> 拥有以下权限：<i>%s</i>。';
$lang['p_user_ns']             = '用户 <b class="acluser">%s</b> 当前在命名空间 <b class="aclns">%s</b> 拥有以下权限：<i>%s</i>。';
$lang['p_group_id']            = '<b class="aclgroup">%s</b> 组成员当前在页面 <b class="aclpage">%s</b> 拥有以下权限：<i>%s</i>。';
$lang['p_group_ns']            = '<b class="aclgroup">%s</b> 组成员当前在命名空间 <b class="aclns">%s</b> 拥有以下权限：<i>%s</i>。';
$lang['p_choose_id']           = '请在上表中<b>输入用户名或组名称</b>，来查看或编辑页面 <b class="aclpage">%s</b> 的权限设置。';
$lang['p_choose_ns']           = '请在上表中<b>输入用户名或组名称</b>，来查看或编辑命名空间 <b class="aclns">%s</b> 的权限设置。';
$lang['p_inherited']           = '请注意：这些权限并没有明确设定，而是从其他组或更高级的名称空间继承而来。';
$lang['p_isadmin']             = '请注意：选定的组或用户拥有完全权限，因为它被设定为超级用户。';
$lang['p_include']             = '高权限包含低权限。创建、上传和删除权限只能应用于名称空间，而不是单个页面。';
$lang['current']               = '当前 ACL 规则';
$lang['where']                 = '页面/命名空间';
$lang['who']                   = '用户/组';
$lang['perm']                  = '权限';
$lang['acl_perm0']             = '无';
$lang['acl_perm1']             = '读取';
$lang['acl_perm2']             = '编辑';
$lang['acl_perm4']             = '创建';
$lang['acl_perm8']             = '上传';
$lang['acl_perm16']            = '删除';
$lang['acl_new']               = '添加新条目';
$lang['acl_mod']               = '编辑条目';
